@@ -19,22 +19,30 @@ class SchedHealth(BaseModel):
 
     def check(self):
         file = tempfile.SpooledTemporaryFile(mode="r+")
-        fp = lib.fdopen(os.dup(file.fileno()), b"r+")
+        fd = os.dup(file.fileno())
+        if fd == -1:
+            raise InternalError(RC.EFAIL, "Failed to duplicate file descriptor.")
+
+        fp = lib.fdopen(fd, b"r+")
+        if fp == ffi.NULL:
+            raise InternalError(RC.EFAIL, "Failed to fdopen a file descriptor.")
 
         p_health = ffi.new("struct sched_health *")
         c_health = p_health[0]
         c_health.fp = fp
         c_health.num_errors = 0
 
-        rc = RC(lib.sched_health_check(p_health))
-
-        if rc != RC.OK:
-            raise InternalError(rc)
+        try:
+            rc = RC(lib.sched_health_check(p_health))
+            if rc != RC.OK:
+                raise InternalError(rc)
+        finally:
+            lib.fclose(fp)
 
         file.flush()
+        file.seek(0)
 
         self.num_errors = int(c_health.num_errors)
-        file.seek(0)
         for row in file:
             self.errors.append(row.strip())
 
